/* eslint-disable @next/next/no-img-element */
import classNames from 'classnames';
import { useCallback, useEffect, useRef, useState } from 'react';
import { useGame } from '../../contexts/GameContext';
import { useUI } from '../../contexts/UIContext';
import { Dimensions, BoardPosition, GameStatus, usePlayerScores } from '../../hooks/useGameContract';
import { Pixel } from './Pixel';
import { ScoreItem } from './ScoreItem';

type Props = {
  className?: string;
  boardWidth: string | number;
  board: BoardPosition[];
  dimensions?: Dimensions;
  status?: GameStatus;
};

type CanvasPosition = {
  top: number;
  left: number;
  right: number;
  bottom: number;
  width: number;
  height: number;
};

export const Board: React.FC<Props> = ({ className, board, dimensions, boardWidth, status }) => {
  const { darkMode } = useUI();
  const pixelBoardRef = useRef<SVGGElement>(null);
  const scoreBoardRef = useRef<SVGGElement>(null);
  const [pixelBoardPosition, setPixelBoardPosition] = useState<CanvasPosition | null>(null);
  const [scoreBoardPosition, setScoreBoardPosition] = useState<CanvasPosition | null>(null);
  const { turnData } = useGame();
  const scores = usePlayerScores();

  const sirenColor = status
    ? {
        Forming: '#ffc32b',
        Running: '#50d985',
        Finished: '#ff705e',
      }[status]
    : '#ffc32b';

  const setPosition = useCallback(() => {
    if (pixelBoardRef && pixelBoardRef.current) {
      setPixelBoardPosition({
        top: pixelBoardRef.current.getBoundingClientRect().top,
        left: pixelBoardRef.current.getBoundingClientRect().left,
        right: pixelBoardRef.current.getBoundingClientRect().right,
        bottom: pixelBoardRef.current.getBoundingClientRect().bottom,
        width: pixelBoardRef.current.getBoundingClientRect().width,
        height: pixelBoardRef.current.getBoundingClientRect().height,
      });
    }
    if (scoreBoardRef && scoreBoardRef.current) {
      setScoreBoardPosition({
        top: scoreBoardRef.current.getBoundingClientRect().top,
        left: scoreBoardRef.current.getBoundingClientRect().left,
        right: scoreBoardRef.current.getBoundingClientRect().right,
        bottom: scoreBoardRef.current.getBoundingClientRect().bottom,
        width: scoreBoardRef.current.getBoundingClientRect().width,
        height: scoreBoardRef.current.getBoundingClientRect().height,
      });
    }
  }, []);

  useEffect(() => {
    setPosition();
    window.addEventListener('resize', setPosition);
    return () => window.removeEventListener('resize', setPosition);
  }, [setPosition]);

  return (
    <div className={className}>
      <>
        {pixelBoardRef && (
          <ul
            className={classNames(
              'z-10 bg-squink-800/80 absolute p-1 rounded-l-sm rounded-r-2xl flex flex-col w-full items-center justify-start overflow-x-hidden overflow-y-scroll',
              darkMode ? 'backdrop-blur-md' : 'backdrop-blur-sm',
            )}
            style={{
              ...scoreBoardPosition,
            }}
          >
            {scores.map((p, index) => (
              <li
                key={p.id}
                className="w-full rounded-xl first:rounded-tl-sm p-2 mt-1 first:mt-0 transition duration-150"
                style={{ backgroundColor: p.color }}
              >
                <ScoreItem player={p} rank={status && status !== 'Forming' ? index + 1 : 0} />
              </li>
            ))}
          </ul>
        )}
        {pixelBoardRef && dimensions && (
          <div
            className={classNames(
              'absolute rounded-l-xl rounded-r-md flex flex-wrap items-center justify-center overflow-hidden backdrop-blur-sm',
              darkMode ? 'bg-white/40' : 'bg-white/70',
            )}
            style={{
              ...pixelBoardPosition,
              display: 'grid',
              gridTemplateColumns: `repeat(${dimensions.x},minmax(0,1fr))`,
            }}
          >
            {board.map(({ x, y, owner, color }) => (
              <Pixel key={`(${x}, ${y})`} events={turnData[`(${x},${y})`]} x={x} y={y} owner={owner} color={color} />
            ))}
          </div>
        )}

        <svg
          className="mx-auto z-6 relative"
          style={{ width: boardWidth }}
          xmlns="http://www.w3.org/2000/svg"
          viewBox="0 0 1537.68 857.71"
        >
          <defs>
            <clipPath id="clippath">
              <path
                fill="none"
                d="M1010.25 107.43c-1.23 42.69-13.75 80.14-19.7 80.14-7.03 0-10.9-37.89-17.84-68.72-.68-3-1.37-5.93-2.11-8.75-1.74-6.67-3.68-12.72-5.89-17.64-13.65-30.39-28.37-15.35-35.35 18.86-2.62 12.8-4.16 28.28-4.16 45.07l-49.24-1.04-30.47-.63c.95-22.09 3.99-41.69 8.59-58.89C882.46-10.43 970.6-24.8 998.04 35.24c9.96 21.78 12.92 47.83 12.22 72.17z"
              ></path>
            </clipPath>
            <clipPath id="clippath-1">
              <path fill="none" d="M479.37 127.17h37.09c0-25.88-37.09-24.71-37.09 0z"></path>
            </clipPath>
            <clipPath id="clippath-2">
              <path
                fill="none"
                d="M1437.85 130.17l13.82 13.82c2.46 2.46 3.84 5.79 3.84 9.27V730.2c0 3.48-1.38 6.81-3.84 9.27l-13.82 13.82a13.101 13.101 0 01-9.27 3.84H126.13c-3.48 0-6.81-1.38-9.27-3.84l-13.82-13.82a13.101 13.101 0 01-3.84-9.27V153.26c0-3.48 1.38-6.81 3.84-9.27l13.82-13.82c2.46-2.46 5.79-3.84 9.27-3.84h1302.45c3.48 0 6.81 1.38 9.27 3.84z"
              ></path>
            </clipPath>
          </defs>
          <g ref={pixelBoardRef}>
            <path
              fill="rgba(255,255,255,0)"
              d="M115.94 166.42v551.65c0 8.28 6.71 15 15 15h969.41c2.02 0 3.66-1.64 3.66-3.66V155.09c0-2.02-1.64-3.66-3.66-3.66H130.93c-8.28 0-15 6.71-15 15z"
            ></path>
          </g>
          <g ref={scoreBoardRef}>
            <path
              fill="rgba(255,255,255,0)"
              d="M1438.69 166.42v551.65c0 8.28-6.72 14.99-15 14.99h-301.37c-2.02 0-3.66-1.63-3.66-3.66V155.09c0-2.02 1.63-3.67 3.66-3.67h301.37c8.28 0 15 6.72 15 15z"
            ></path>
          </g>
          <g>
            <g>
              <path
                fill="#bc83fb"
                d="M1526.08 217.54c-11.1 7.38-30.26 18.41-55.74 26.68-9.17 2.98-19.18 5.59-29.91 7.56v46.21c8.08-3.66 18.65-9.07 30.13-16.56 19.97-13.02 42.64-32.31 59.56-59.57 1.73-2.79-1.36-6.1-4.04-4.33z"
              ></path>
              <path
                fill="#8747cc"
                d="M1440.43 251.78v46.21c8.08-3.66 18.65-9.07 30.13-16.56-1.54-6.52-3.15-18.88-.22-37.21-9.17 2.98-19.18 5.59-29.91 7.56zM34.12 673.41c29.23-32.65 25.17-48.88.47-95.6-1.07-2.03-3.89-2.33-5.34-.56-44.94 54.71-9.57 88.61.45 96.54 1.35 1.06 3.28.89 4.43-.39zM331.97 738.1c-10.09 101.09-93.42 101.54-103.13 111.44-1.97 2 3.22 4.65 13.01 6.37 38.75 6.83 149.65-.62 175.71-117.82h-85.59z"
              ></path>
              <path
                fill="#bc83fb"
                d="M381.73 738.1c-3.06 15.03-7.5 28.35-13.02 40.09-29.81 63.65-90.39 81.33-126.86 77.72 31.98 5.64 113.11 1.56 155.15-65.94 8.88-14.28 16.02-31.41 20.57-51.88h-35.83z"
              ></path>
              <ellipse
                cx="333.19"
                cy="794.71"
                fill="#d8b7fb"
                rx="21.29"
                ry="11.52"
                transform="rotate(-52.31 333.166 794.69)"
              ></ellipse>
              <ellipse
                cx="289.5"
                cy="835.57"
                fill="#d8b7fb"
                rx="15.3"
                ry="7.22"
                transform="rotate(-27.09 289.54 835.647)"
              ></ellipse>
              <path
                fill="#8747cc"
                d="M381.73 738.1c-3.06 15.03-7.5 28.35-13.02 40.09 12.89 3.5 22.32 8.2 28.29 11.79 8.88-14.28 16.02-31.41 20.57-51.88h-35.83zM1443.53 457.62v68.89c43.97 35.9 46.32 83 24.62 108.5a7.847 7.847 0 01-9.35 2.03c-36.33-17.15-68.21-17.64-34.69-1.29 9.93 4.85 21.6 8.65 33.35 10.27 2.12.29 4.26.52 6.38.67 4.06.29 8.11.28 12.06-.06v-.02c22.86-1.92 42.77-14.88 46.79-47.86 6.76-55.55-18.09-110.07-79.17-141.13z"
              ></path>
              <path
                fill="#bc83fb"
                d="M1483.89 474.64a150.77 150.77 0 00-18.99-15.15c-6.57-4.43-13.7-8.52-21.37-12.24v33.83c1.21.79 2.41 1.59 3.58 2.41 7 4.88 13.33 10.2 19.04 15.84 54.93 54.31 51.52 138.66 9.77 147.29 22.87-1.92 49.47-15.92 53.73-48.87 6.12-47.3-12.02-91.37-45.76-123.11z"
              ></path>
              <g fill="#d8b7fb">
                <ellipse
                  cx="1486.43"
                  cy="625.24"
                  rx="8.48"
                  ry="5.12"
                  transform="rotate(-66.76 1486.549 625.222)"
                ></ellipse>
                <ellipse
                  cx="1492.37"
                  cy="583.2"
                  rx="6.51"
                  ry="10.52"
                  transform="rotate(-6.43 1493.348 583.574)"
                ></ellipse>
                <path d="M1522.86 558.13c1.5 8.44.42 15.62-1.69 15.99-2.11.37-3.65-6.14-5.15-14.58-1.5-8.44-2.38-15.61-.27-15.98s5.61 6.13 7.11 14.57z"></path>
                <ellipse
                  cx="1473.65"
                  cy="538.55"
                  rx="7.69"
                  ry="13.3"
                  transform="rotate(-30.75 1473.68 538.556)"
                ></ellipse>
                <path d="M1443.53 494.45v16.1c2.6-.2 4.63-1.13 5.64-2.84 1.98-3.34-.47-8.65-5.64-13.26z"></path>
              </g>
              <path
                fill="#8747cc"
                d="M559.6 104.25c6.96.74 11.8-26.99 42.34-32.55 28.15-5.13 69.65-.39 66.92 77.31h70.38c-2.8-94.17-58.55-140.25-129.72-111.28-7.53 3.07-14.18 7.12-19.98 11.71-26.91 21.29-35.66 54.22-29.94 54.81z"
              ></path>
              <path
                fill="#bc83fb"
                d="M704.04 93.25c5.07 14.98 7.17 33.44 5.06 55.76h30.15c-.72-24.29-4.96-45.38-12.09-62.8-20.5-50.15-64.83-69.98-117.64-48.47-7.53 3.07-14.18 7.12-19.98 11.71 33.69-20.12 95.29-13.07 114.5 43.81z"
              ></path>
              <ellipse
                cx="660.17"
                cy="67.54"
                fill="#d8b7fb"
                rx="10.04"
                ry="17.21"
                transform="rotate(-50.69 660.224 67.52)"
              ></ellipse>
              <ellipse cx="687.14" cy="124.44" fill="#d8b7fb" rx="11.46" ry="23.1"></ellipse>
              <ellipse
                cx="611.48"
                cy="56.71"
                fill="#d8b7fb"
                rx="12.33"
                ry="7.2"
                transform="rotate(-13.09 611.69 56.713)"
              ></ellipse>
              <path
                fill="#8747cc"
                d="M709.11 149.01h30.15c-.51-17.2-2.79-32.79-6.6-46.61-9.35 4.13-17.91 6.19-24.54 7.19 1.95 11.51 2.4 24.62 1 39.43z"
              ></path>
              <g>
                <path
                  fill="#bc83fb"
                  d="M115.22 226.5c-7.81-1.48-14.98-3.38-21.51-5.56-36.4-12.13-53.29-32.55-53.29-32.55-14.14-36.85-18.95-86.02-26.6-94.03-5.94-6.23-6.96 11.81-4.61 39.76 3.76 44.56 12.19 94.06 51.14 127.92 13.96 12.15 31.87 22.26 54.87 29.43v-64.98z"
                ></path>
                <path
                  fill="#8747cc"
                  d="M115.22 226.5c-51.3-9.69-74.79-38.12-74.79-38.12 12.47 30.08 33.7 64.95 74.79 86.33V226.5z"
                ></path>
                <path
                  fill="#8747cc"
                  d="M115.22 226.5c-7.81-1.48-14.98-3.38-21.51-5.56-2.98 21-19.72 33.93-33.35 41.1 13.96 12.15 31.87 22.26 54.87 29.43v-64.98z"
                ></path>
                <ellipse
                  cx="91.61"
                  cy="235.57"
                  fill="#d8b7fb"
                  rx="8.49"
                  ry="20.37"
                  transform="rotate(-59.89 91.62 235.587)"
                ></ellipse>
              </g>
              <g>
                <path
                  fill="#8747cc"
                  d="M744.48 785.19c-21.78 29.03-71.78 10.72-80.83-47.09h-62.11c2.36 48.38 21.87 80.39 46.99 96.54 39.88 25.64 96.18 11.34 117.72-40.65l.03-.03c1.74-4.18 3.27-8.6 4.55-13.26 5.24-18.95-2.6-27.09-26.35 4.5z"
                ></path>
                <path
                  fill="#d8b7fb"
                  d="M745.03 795.72c1.64 2.22-1.95 7.52-8.01 11.84-6.06 4.31-12.3 6.01-13.94 3.78-1.64-2.22 1.78-8.38 7.84-12.69 6.06-4.31 12.46-5.15 14.1-2.92z"
                ></path>
                <path
                  fill="#bc83fb"
                  d="M636.12 769.1c-2.82-9.23-4.84-19.55-5.9-31h-28.68c.93 18.32 4.4 34.25 9.42 47.96 30.83 84.18 106 76.04 133.51-.87-30.66 52.33-85.58 58.23-108.36-16.1z"
                ></path>
                <path
                  fill="#d8b7fb"
                  d="M700.34 812.42c-2.61 4.04-12.19 2.33-21.41-3.81-9.22-6.15-14.58-14.41-11.98-18.45s13.41-3.19 22.63 2.96c9.22 6.15 13.37 15.26 10.76 19.3zM656.56 738.1h-12.61c-1.95 4.06-2.2 10.69-.29 17.74 2.88 10.6 9.57 18.1 14.93 16.74 5.36-1.36 7.37-11.05 4.48-21.66-1.44-5.28-3.82-9.79-6.51-12.82z"
                ></path>
                <path
                  fill="#8747cc"
                  d="M601.53 738.1c.89 18.33 4.24 34.31 9.43 47.96 6.19-5.68 14.52-11.89 25.16-16.97-2.82-9.23-4.84-19.55-5.9-31h-28.69z"
                ></path>
                <path
                  fill="#bc83fb"
                  d="M772.83 780.69c-1.28 4.66-2.81 9.09-4.55 13.26l-.03.03c-26.26 59.61-81.27 68.48-121.14 42.84l2.52-3.43c73.35 6 94.85-48.21 94.85-48.21 23.75-31.6 33.59-23.45 28.35-4.5z"
                ></path>
              </g>
              <path
                fill="#8747cc"
                d="M1464.9 459.5c-6.57-4.43-13.7-8.52-21.37-12.24v33.83c1.21.79 2.41 1.59 3.58 2.41 7 4.88 13.33 10.2 19.04 15.84 0 0 4.34-23.36 17.74-24.69a150.77 150.77 0 00-18.99-15.15z"
              ></path>
              <path
                fill="#bc83fb"
                d="M1260.73 787.1c-20.15-10.25-41.71-13.88-62.99-4.45-6.66 2.78-12.82 6.21-18.85 9.34-6.04 3.13-12 5.96-18.14 7.72-6.18 1.82-12.57 2.34-18.97 2.24-19.28-.26-37.69-8.17-51.99-20.83a86.692 86.692 0 01-13.39-14.92c-5.55-7.69-9.95-16.06-13.39-24.83h-15.69c6.62 17.27 17.12 33.5 30.78 46.03 11.78 10.82 25.89 18.9 41.83 22.55 14.29 3.32 29.62 3.52 43.67-.9 13.62-4.3 25.02-12.82 37.56-18.5 25.67-12.48 51.76-1.39 74.17 12.8 5.73 3.63 11.32 7.53 16.79 11.61l3.9-5.13c-11.04-8.47-22.61-16.41-35.29-22.73z"
              ></path>
              <g>
                <path
                  fill="#8747cc"
                  d="M1362.8 833.32c-.18.02-.37.05-.55.07-72.64 9.59-91.13-14.92-98.06-37.9-.64-2.13.73-4.35 2.93-4.69 3.12-.49 6.09-.92 8.91-1.28 62.94-8.03 53.7 15.38 88.09 38.1 2.4 1.58 1.54 5.32-1.31 5.69z"
                ></path>
                <path
                  fill="#bc83fb"
                  d="M1362.8 833.32c-.18.02-.37.05-.55.07-26.95-7.93-45.2-44.16-86.23-43.86 62.94-8.03 53.7 15.38 88.09 38.1 2.4 1.58 1.54 5.32-1.31 5.69z"
                ></path>
                <g fill="#d8b7fb">
                  <ellipse
                    cx="1300.05"
                    cy="806.55"
                    rx="5.72"
                    ry="12.05"
                    transform="rotate(-68.35 1300.079 806.551)"
                  ></ellipse>
                  <ellipse
                    cx="1329.46"
                    cy="824.08"
                    rx="4.4"
                    ry="10.38"
                    transform="rotate(-68.35 1329.504 824.077)"
                  ></ellipse>
                  <ellipse
                    cx="1302.97"
                    cy="823.64"
                    rx="5.63"
                    ry="11.11"
                    transform="rotate(-71.11 1302.959 823.643)"
                  ></ellipse>
                  <ellipse
                    cx="1279.94"
                    cy="809.67"
                    rx="4"
                    ry="7.79"
                    transform="rotate(-52.88 1279.897 809.667)"
                  ></ellipse>
                </g>
              </g>
              <path
                fill="#bc83fb"
                d="M203.73 738.1c-6.77 16.27-15.83 32.54-27.43 45.63-13.9 15.69-31.42 26.81-52.94 27.87-67.92.8-85.78-110.22-89.43-162.36-1.42-19.69-1.69-39.49-1.1-59.28-.07-2.77-3.78-2.73-4.08-.22-6.46 66.67 4.08 230.36 94.69 231.88 21.55.13 41.61-10.89 56.67-25.46 1.83-1.82 3.61-3.68 5.32-5.58 14-15.43 24.47-33.34 32.38-52.48h-14.08z"
              ></path>
              <path
                fill="#8747cc"
                d="M1076.4 766.2c-5.55-7.69-9.95-16.06-13.39-24.83h-15.69c6.62 17.27 17.12 33.5 30.78 46.03a77.47 77.47 0 0011.69-6.28 86.692 86.692 0 01-13.39-14.92zM203.73 738.1c-6.77 16.27-15.83 32.54-27.43 45.63 3.08 2.97 6.22 5.19 9.13 6.85 14-15.43 24.47-33.34 32.38-52.48h-14.08z"
              ></path>
              <g>
                <path
                  fill="#bc83fb"
                  d="M998.03 35.26c-27.44-60.04-115.58-45.67-143.96 60.59-4.2 15.69-7.09 33.4-8.28 53.16h79.51c.38-13.94 1.82-26.78 4.05-37.68 6.99-34.21 21.71-49.25 35.35-18.86 2.22 4.92 4.16 10.97 5.89 17.64.74 2.82 1.43 5.75 2.11 8.75 6.94 30.83 10.81 68.72 17.84 68.72 5.94 0 18.47-37.45 19.7-80.14.7-24.34-2.26-50.39-12.22-72.17z"
                ></path>
                <path fill="#d8b7fb" d="M989.54 38.2c-4.09 4.69 4.2 35.89 9.4 33.08s-6.43-36.48-9.4-33.08z"></path>
                <path
                  fill="#8747cc"
                  d="M925.31 149.01c.38-13.94 1.82-26.78 4.05-37.68-16.52.94-52.92.87-75.28-15.48-4.2 15.69-7.09 33.4-8.28 53.16h79.51z"
                ></path>
                <g clipPath="url(#clippath)">
                  <path
                    fill="none"
                    stroke="#9959de"
                    strokeMiterlimit="10"
                    strokeWidth="4"
                    d="M966.61 0c-54.14 9.33-28.38 52.97-28.38 52.97"
                  ></path>
                </g>
                <path
                  fill="#8747cc"
                  d="M876.62 149.01h48.69c1.57-57.71 21.4-96.62 39.4-56.54 1.89 4.2 3.58 9.23 5.12 14.76.28 1 1.77.7 1.63-.32-13.38-102.05-82.58-65.13-94.84 42.1z"
                ></path>
                <ellipse
                  cx="909.08"
                  cy="112.97"
                  fill="#d8b7fb"
                  rx="23.92"
                  ry="11.76"
                  transform="rotate(-76.72 909.05 112.983)"
                ></ellipse>
                <path
                  fill="#d8b7fb"
                  d="M941.36 71.32c-6.75 3.56-10.98 8.4-13.15 4.29s.28-11.9 7.03-15.46 15.23-1.53 17.4 2.58c2.17 4.11-4.54 5.03-11.28 8.59z"
                ></path>
              </g>
            </g>
            <g>
              <path
                fill="#8747cc"
                d="M96.29 685.1l6.04 1.55v-84.12l-6.04 1.55a5.113 5.113 0 00-3.84 4.95v71.11c0 2.33 1.58 4.37 3.84 4.95z"
              ></path>
              <path
                fill="none"
                stroke="#8747cc"
                strokeLinejoin="round"
                strokeWidth="4"
                d="M497.91 110.05v-9.15c29.37-3.92 14.4-21.88-4.49-10.82 17.51-21.88 2.99-30.41-12.67-5.53 2.99-23.73-18.66-26.72-10.71 1.09-11.64-16.75-28.68-9.61-11.87 9.28-22.8-12.9-27.64 9.44-.92 11.52-20.56 1.38-27.41 15.3-1.38 15.3-24.65 5.2-20.04 14.65 5.3 14.65"
              ></path>
              <path fill="#0e0e0e" d="M479.37 127.17h37.09c0-25.88-37.09-24.71-37.09 0z"></path>
              <g clipPath="url(#clippath-1)">
                <path
                  fill="none"
                  stroke="#8747cc"
                  strokeMiterlimit="10"
                  strokeWidth="4"
                  d="M519.05 118.66L476.89 118.66"
                ></path>
              </g>
              <path
                fill="none"
                stroke="#8747cc"
                strokeMiterlimit="10"
                strokeWidth="4"
                d="M1200.47 97.2V78.13c0-5.26 4.26-9.52 9.52-9.52h6.41c5.26 0 9.52 4.26 9.52 9.52v52.11"
              ></path>
              <path
                fill="none"
                stroke="#0e0e0e"
                strokeMiterlimit="10"
                strokeWidth="4"
                d="M1145.79 88.37V60.49c0-3.73 3.02-6.75 6.75-6.75h7.83c6.27 0 11.52 4.76 12.12 11.01l6.2 63.99"
              ></path>
              <path
                fill="#8747cc"
                d="M1138.3 126.34V92.62c0-2.97 2.41-5.38 5.38-5.38h4.1c2.97 0 5.38 2.41 5.38 5.38v33.72h-14.86z"
              ></path>
              <path
                fill="none"
                stroke="#0e0e0e"
                strokeMiterlimit="10"
                strokeWidth="4"
                d="M1153.17 101.09L1138.3 101.09"
              ></path>
              <path
                fill="#bc83fb"
                d="M1192.25 126.34v-22.89c0-4.48 3.63-8.11 8.11-8.11 4.48 0 8.11 3.63 8.11 8.11v22.89h-16.22z"
              ></path>
              <path
                fill="none"
                stroke="#8747cc"
                strokeMiterlimit="10"
                strokeWidth="4"
                d="M1208.47 111.71L1192.25 111.71"
              ></path>
              <path
                fill="none"
                stroke="#8747cc"
                strokeMiterlimit="10"
                strokeWidth="4"
                d="M1208.47 119.18L1192.25 119.18"
              ></path>
              <path
                fill={sirenColor}
                d="M195.08 117.74s-1.7-34.16-3.65-40.24-14.26-5.3-21.5-3.85c-7.24 1.45-7.06 13.9-7.06 20.98v23.11h32.21z"
              ></path>
              <path
                fill="none"
                stroke="#ffffab"
                strokeLinecap="round"
                strokeMiterlimit="10"
                strokeWidth="4.84"
                d="M185.31 91.68L178.94 96.91 172.1 89.33"
              ></path>
              <path
                fill="none"
                stroke="#ffffab"
                strokeLinecap="round"
                strokeMiterlimit="10"
                strokeWidth="4.84"
                d="M178.97 96.91L178.97 117.74"
              ></path>
              <path
                fill="#bc83fb"
                d="M147.86 126.45l3.08-8.31a5.62 5.62 0 015.26-3.66h44.01a5.6 5.6 0 015.26 3.66l3.08 8.31h-60.71z"
              ></path>
              <path
                fill="#8747cc"
                d="M43.58 359.75a23.788 23.788 0 00-10.03 19.41V500.4c0 7.71 3.74 14.94 10.03 19.41l61.55 43.64V316.11l-61.55 43.64z"
              ></path>
              <path
                fill="#8747cc"
                d="M1104.01 729.41c0 2.02-1.64 3.66-3.66 3.66H130.94c-8.28 0-15-6.71-15-15V166.42c0-8.28 6.72-14.99 15-14.99h969.41c2.02 0 3.66 1.64 3.66 3.66v574.32zm351.49-567.69c-.08-3.36-1.45-6.57-3.83-8.95l-13.82-13.82a13.101 13.101 0 00-9.27-3.84H126.13c-3.47 0-6.8 1.38-9.26 3.84l-13.82 13.82a13.101 13.101 0 00-3.84 9.27v576.94c0 3.47 1.38 6.81 3.84 9.27l13.82 13.82c2.46 2.45 5.79 3.83 9.26 3.83h1302.45c3.48 0 6.81-1.38 9.27-3.83l13.82-13.82c2.46-2.46 3.84-5.8 3.84-9.27V162.04v-.32zm-336.84 70.88c27.84 17.41 43.37-1.7 63.85-1.7s27.23 10.39 41.55 10.39 29.08-10.39 42.89-10.39 21.99 10.39 40.65 10.39 32.98-10.39 49.31-10.39 21.66 10.39 36.98 10.39 24.91-10.39 44.8-10.39v487.18c0 8.28-6.71 14.99-15 14.99h-301.37c-2.02 0-3.66-1.64-3.66-3.66V232.6z"
              ></path>
              <path
                fill="#bc83fb"
                d="M1104.01 729.41c0 2.02-1.64 3.66-3.66 3.66H130.94c-8.28 0-15-6.71-15-15V166.42c0-8.28 6.72-14.99 15-14.99h969.41c2.02 0 3.66 1.64 3.66 3.66v574.32zM1451.67 144l-13.82-13.82a13.101 13.101 0 00-9.27-3.84H126.13c-3.47 0-6.8 1.38-9.26 3.84L103.05 144a13.095 13.095 0 00-3.84 9.26V730.2c0 3.47 1.38 6.82 3.84 9.27l13.82 13.82c2.46 2.46 5.79 3.84 9.26 3.84h1302.45c3.48 0 6.81-1.38 9.27-3.84l13.82-13.82c2.46-2.45 3.83-5.8 3.83-9.27V153.26c0-3.47-1.37-6.8-3.83-9.26zm-12.98 574.08c0 8.28-6.71 14.99-15 14.99h-301.37c-2.02 0-3.66-1.64-3.66-3.66V232.6c27.84 17.41 43.37-1.7 63.85-1.7s27.23 10.39 41.55 10.39 29.08-10.39 42.89-10.39 21.99 10.39 40.65 10.39 32.98-10.39 49.31-10.39 21.66 10.39 36.98 10.39 24.91-10.39 44.8-10.39v487.18z"
              ></path>
              <path
                fill="#d8b7fb"
                d="M1260.37 126.34c-23.1 18.12-123.46 26.47-181.99.82 0 0-53.6 17.13-87.25-.82h269.24z"
              ></path>
              <path
                fill="#e2dcfe"
                d="M1438.69 166.43v64.47c-19.89 0-29.47 10.39-44.8 10.39s-20.66-10.39-36.98-10.39-30.65 10.39-49.31 10.39-26.84-10.39-40.65-10.39-28.56 10.39-42.89 10.39-21.06-10.39-41.55-10.39-36.01 19.11-63.85 1.7v-77.51a3.67 3.67 0 013.66-3.67h301.37c8.29 0 15 6.72 15 15.01z"
              ></path>
              <g fill="none" stroke="#0e0e0e" strokeLinecap="round" strokeMiterlimit="10" strokeWidth="5">
                <path d="M1311.87 142.67L1301.39 135.04"></path>
                <path d="M1331.5 142.67L1321.02 135.04"></path>
                <path d="M1351.13 142.67L1340.65 135.04"></path>
                <path d="M1370.76 142.67L1360.29 135.04"></path>
                <path d="M1390.39 142.67L1379.92 135.04"></path>
                <path d="M1399.55 135.04L1410.02 142.67"></path>
              </g>
              <path
                fill="none"
                stroke="#8747cc"
                strokeLinecap="round"
                strokeMiterlimit="10"
                strokeWidth="4"
                d="M365.03 139.29L178.22 139.29"
              ></path>
              <circle cx="147.6" cy="138.94" r="3.14" fill="#0e0e0e"></circle>
              <circle cx="129.7" cy="138.94" r="5.57" fill={sirenColor}></circle>
              <g>
                <path fill="#8747cc" d="M271.52 126.34L277.93 119.69 391.87 119.69 396.97 126.34 271.52 126.34z"></path>
                <path
                  fill="#0e0e0e"
                  d="M332.36 119.69v-4c0-.97-.79-1.76-1.76-1.76h-21.84c-.97 0-1.76.79-1.76 1.76v4h25.36z"
                ></path>
              </g>
              <g fill="#0e0e0e">
                <circle cx="156.05" cy="743.54" r="3.84"></circle>
                <circle cx="169.01" cy="748.2" r="3.84"></circle>
                <circle cx="181.96" cy="743.54" r="3.84"></circle>
                <circle cx="220.52" cy="748.2" r="3.84"></circle>
                <circle cx="207.56" cy="743.54" r="3.84"></circle>
                <circle cx="194.61" cy="748.2" r="3.84"></circle>
              </g>
              <g clipPath="url(#clippath-2)">
                <path
                  fill="none"
                  stroke="#8747cc"
                  strokeLinecap="round"
                  strokeMiterlimit="10"
                  strokeWidth="4"
                  d="M1117.51 125.04l-8.72 9.51a11.826 11.826 0 01-8.73 3.84H438.5c-3.32 0-6.48-1.39-8.73-3.84l-8.95-9.75"
                ></path>
              </g>
              <g fill="#8747cc">
                <path d="M1050.69 757.33h-21.68c0-4.62 4.85-8.37 10.84-8.37s10.84 3.75 10.84 8.37zM1093.53 757.33h-21.68c0-4.62 4.85-8.37 10.84-8.37s10.84 3.75 10.84 8.37zM1136.38 757.33h-21.68c0-4.62 4.85-8.37 10.84-8.37s10.84 3.75 10.84 8.37zM1179.22 757.33h-21.68c0-4.62 4.85-8.37 10.84-8.37s10.84 3.75 10.84 8.37z"></path>
              </g>
              <g>
                <path
                  fill="#bc83fb"
                  d="M43.58 348.78a23.788 23.788 0 00-10.03 19.41v121.24c0 7.71 3.74 14.94 10.03 19.41l61.55 43.64V305.14l-61.55 43.64z"
                ></path>
                <circle cx="88.54" cy="338.22" r="3.37" fill="#0e0e0e"></circle>
                <circle cx="77.49" cy="346.4" r="4.52" fill="#8747cc"></circle>
                <circle cx="94.72" cy="514.27" r="9.03" fill="#8747cc"></circle>
                <circle cx="94.72" cy="515.38" r="4.47" fill="#e2dcfe"></circle>
                <g>
                  <g>
                    <path
                      fill="#bc83fb"
                      fillRule="evenodd"
                      d="M58.33 400.24s-.56-2.56-1.23-5.6a11.815 11.815 0 015.69-12.81c2.92-1.67 6.08-4.29 8.37-8.36"
                    ></path>
                    <path d="M56.95 400.55l-1.23-5.6c-.61-2.78-.33-5.62.83-8.22 1.15-2.6 3.07-4.72 5.54-6.12 3.36-1.92 6-4.55 7.84-7.83a1.41 1.41 0 112.46 1.38c-2.1 3.73-5.09 6.72-8.9 8.89-3.99 2.27-6 6.81-5.02 11.29l1.23 5.6-2.75.61z"></path>
                    <path
                      fill="#bc83fb"
                      fillRule="evenodd"
                      d="M93.29 400.24l.8-3.58a9.546 9.546 0 00-4.9-10.54c-3.84-2.02-7.95-5.78-8.31-12.66l-.06 23.15 12.47 3.62z"
                    ></path>
                    <path d="M93.29 401.65c-.13 0-.26-.02-.39-.06l-12.48-3.62c-.6-.17-1.02-.73-1.01-1.35l.06-23.15a1.406 1.406 0 012.81-.07c.27 5.13 2.81 8.99 7.56 11.49 4.38 2.29 6.69 7.27 5.62 12.09l-.8 3.58c-.08.38-.32.71-.66.9-.22.13-.47.2-.72.2zm-11.07-6.09l10.02 2.91.47-2.11c.8-3.59-.92-7.29-4.18-8.99-2.12-1.11-4.49-2.82-6.28-5.38l-.04 13.57z"></path>
                    <g>
                      <path
                        fill="#bc83fb"
                        fillRule="evenodd"
                        d="M73.53 368.98s.58-2.68 3.58-2.7c1.66-.01 3.12 1.1 3.58 2.7l2.05 15.11a9.23 9.23 0 002.47 5.15c4.71 4.97 15.18 18.43 4.91 31 0 0-.81-10.64-13.65-10.64h-.44c-12.84 0-14.52 10.64-14.52 10.64-12.91-15.81 8.08-42.22 12.02-51.26z"
                      ></path>
                      <path d="M61.51 421.98c-.51 0-1.01-.23-1.34-.64-11.1-13.6.79-33.89 7.9-46.01 1.64-2.8 3.06-5.22 3.82-6.92.4-1.43 1.91-3.84 5.21-3.86h.03c2.41 0 4.55 1.62 5.22 3.95.05.19.08.41.12.68l1.99 14.67a7.56 7.56 0 002.01 4.2c2.27 2.4 6.39 7.31 8.45 13.28 1.15 3.32 1.54 6.58 1.15 9.68-.46 3.68-2.01 7.15-4.6 10.33a1.733 1.733 0 01-3.07-.96c0-.01-.22-2.34-1.79-4.59-2.07-2.95-5.47-4.44-10.13-4.44h-.44c-11.14 0-12.75 8.81-12.81 9.18a1.743 1.743 0 01-1.71 1.46zm13.7-52.61c-.02.1-.06.2-.1.3-.82 1.89-2.32 4.45-4.06 7.41-3.37 5.75-7.98 13.61-10.36 21.36-2.25 7.33-2.15 13.24.33 17.95.39-.79.9-1.66 1.55-2.52 2.05-2.69 5.98-5.89 13.09-6H76.83c4.04.06 9.39 1.2 12.7 6.07.52.76.92 1.53 1.24 2.25 2.29-4.18 2.58-8.79.87-13.74-1.85-5.35-5.61-9.83-7.69-12.03-1.6-1.69-2.61-3.8-2.92-6.11-.66-4.86-1.86-13.73-2.03-14.96-.28-.8-1.03-1.35-1.87-1.34-1.44 0-1.82 1.03-1.9 1.36zm-1.69-.39z"></path>
                    </g>
                  </g>
                  <path
                    fill="#bc83fb"
                    fillRule="evenodd"
                    d="M89.02 424.42c4.34 1.87 5.82 7.22 4.65 11.66-5.52 28.4-19.79 53.45-25.59 55.4 0 0 1.06-7 1.58-10.48.23-1.53.15-3.09-.24-4.58-1.54-5.85-5.16-10.79-6.61-16.43-2.19-8.47-2.78-17.67-5.63-28.01a6.73 6.73 0 013.33-7.74c3.96-.77.59-5.2.4-8.47 3.07-9.24 5.56-12.41 13.71-12.51 8.84-.8 13.81 6.06 16.09 12.35-.75 7.95-2.13 7.26-1.69 8.79z"
                  ></path>
                  <g>
                    <path
                      fill="#5a007e"
                      fillRule="evenodd"
                      d="M90.5 449.13c-8.1 32.33-3.73 35.46-3.73 35.46l-5.83-5.48"
                    ></path>
                    <path d="M86.76 486.31c-.35 0-.7-.11-1.01-.32-.09-.07-.19-.15-.29-.25l-5.73-5.38c-.7-.66-.73-1.75-.08-2.45.65-.7 1.75-.73 2.45-.08l1.75 1.64c-.17-5.22.86-14.46 4.95-30.77a1.73 1.73 0 012.1-1.26 1.73 1.73 0 011.26 2.1c-2.99 11.92-4.61 21.18-4.83 27.51-.16 4.64.53 6.09.65 6.31.62.63.67 1.63.11 2.32-.34.42-.84.63-1.34.63zm1.25-2.92z"></path>
                    <g>
                      <path
                        fill="#5a007e"
                        fillRule="evenodd"
                        d="M62.17 457.31c.51 13.98 3.23 22.01-1.66 24.48 0 0 5.15-.15 7.77-4.4"
                      ></path>
                      <path d="M60.51 483.52c-.79 0-1.48-.54-1.68-1.31-.2-.79.17-1.61.9-1.97 2.37-1.19 2.14-4.88 1.45-12.45-.28-3.03-.59-6.47-.74-10.42-.04-.96.71-1.76 1.67-1.79.96-.03 1.76.71 1.79 1.67.14 3.86.45 7.24.73 10.23.36 3.98.65 7.12.39 9.64-.05.45-.12.94-.23 1.45a6.86 6.86 0 002.02-2.09c.5-.81 1.57-1.07 2.38-.56.81.5 1.07 1.57.56 2.38-3.08 4.99-8.95 5.22-9.19 5.22h-.05z"></path>
                    </g>
                  </g>
                  <g fillRule="evenodd">
                    <path
                      fill="#d8b6ff"
                      d="M86.86 425.82l3.86 2.35c1.13.69 1.69 2.02 1.39 3.3-1.7 7.26-7.36 30.72-11.07 37.44l-.11.4-.37 1.39c-.31 1.48-.65 3.27-.63 2.37l.63-2.37c.16-.79.32-1.5.41-1.66l.07-.14c4.89-18.12 8.94-31.65-.54-39.06 3.3-.57 5.42-1.87 6.37-4.04z"
                    ></path>
                    <path
                      fill="#5a007e"
                      d="M75.49 370.42c.06-1.43-2.42 5.14-2.58 5.64-4.37 13.88-16.15 22.13-11.28 38.39.04.14.51-.81 1.44-2.46 2.64-4.69 9.8-6.01 9.8-6.01-13.62-10.61 2.15-24.8 2.62-35.56z"
                    ></path>
                    <path
                      fill="#d8b6ff"
                      d="M78.1 371.28c.34-1.38.94 2.96.85 3.47-2.53 13.45 17.91 25.06 10.85 40.56-.03.07-.54-2.36-1.93-4.19-1.44-1.9-3.77-3.2-3.77-3.2 7.57-8.5-10.47-18.65-6-36.64z"
                    ></path>
                    <path
                      fill="#5a007e"
                      d="M69.36 429.41c-9.12 7.54 1.29 39.43 2.34 52.47.01.14-.04.28-.06.41-.23 1.41-.22-2.43-.28-2.95-.52-4.42-2.85-10.95-5.43-16.39-2.67-5.64-3.09-14.42-3.71-20.45-1-9.8-4.38-12.29 2.02-17.22.02-.01.2.06.48.21.71 1.9 2.25 3.17 4.62 3.91z"
                    ></path>
                    <path
                      fill="#d8b6ff"
                      d="M69.89 429.57l.22.05c-1.97 2.85-4.51 12.9.14 40.43-1.13-6.72-7.32-32.16-.5-40.53l.14.04z"
                    ></path>
                    <path
                      fill="#5a007e"
                      d="M70.5 429.72c1.44.32 3.13.47 5.07.48-5.31 2.56-8.07 6.26-3.11 31.67 1.45 7.41-.81 14.66-.76 20.02 0 .14-.04.28-.06.41-.23 1.41-.22-2.43-.28-2.95-1.7-20.15-4.45-37.89-.86-49.64z"
                    ></path>
                  </g>
                  <path d="M68.08 493.22c-.4 0-.8-.14-1.11-.4-.46-.39-.69-.99-.6-1.59l1.58-10.48c.2-1.3.13-2.61-.2-3.89-.73-2.78-2-5.44-3.24-8.02-1.28-2.68-2.61-5.44-3.37-8.41-1.01-3.91-1.67-7.92-2.38-12.15-.77-4.64-1.57-9.44-2.89-14.52a9.688 9.688 0 015.36-11.29c.04-.02.07-.04.11-.05.88-.39 1.9 0 2.28.88.39.87 0 1.9-.88 2.29a6.23 6.23 0 00-3.52 7.3c1.36 5.23 2.17 10.11 2.95 14.82.69 4.16 1.34 8.09 2.32 11.86.68 2.64 1.88 5.14 3.14 7.78 1.3 2.72 2.65 5.54 3.47 8.64.45 1.74.54 3.51.28 5.28l-.92 6.09c2.26-2.57 5.4-7.21 8.97-14.42 3.27-6.59 9.24-20.19 12.54-37.18 0-.04.02-.09.03-.12 1.24-4.69-.96-8.46-3.66-9.62-.88-.38-1.28-1.4-.9-2.28.38-.88 1.4-1.28 2.28-.9 2.46 1.06 4.35 3.15 5.34 5.87.88 2.43.99 5.19.32 7.77-2.51 12.87-7.06 26.37-12.82 38-2.46 4.96-5.01 9.3-7.38 12.55-2.55 3.49-4.68 5.49-6.52 6.11-.18.06-.37.09-.55.09zm25.59-57.13z"></path>
                  <g>
                    <path
                      fill="#d8b6ff"
                      fillRule="evenodd"
                      d="M77.85 472.35c-.53 2.1.34 4.16 1.93 4.6 1.59.44 3.31-.9 3.84-3 .53-2.1-.34-4.16-1.93-4.6-1.59-.44-3.31.9-3.84 3z"
                    ></path>
                    <path d="M80.39 478.76c-.36 0-.72-.05-1.08-.15-2.53-.7-3.91-3.64-3.15-6.69.41-1.64 1.4-3.02 2.7-3.78 1.03-.6 2.2-.77 3.28-.47 2.53.7 3.91 3.64 3.15 6.69-.41 1.64-1.4 3.02-2.7 3.78-.7.41-1.45.61-2.2.61zm-.87-5.99c-.3 1.22.13 2.35.72 2.51.18.05.39 0 .61-.12.49-.28.9-.91 1.08-1.63.3-1.22-.13-2.35-.72-2.51-.18-.05-.38 0-.61.12-.49.28-.9.91-1.08 1.63z"></path>
                    <path
                      fill="#d8b6ff"
                      fillRule="evenodd"
                      d="M81.05 462.3c-.72 2.65.32 5.28 2.32 5.89 2.01.6 4.22-1.06 4.95-3.7.72-2.65-.32-5.28-2.32-5.89-2.01-.6-4.22 1.06-4.95 3.7z"
                    ></path>
                    <path d="M84.21 470.04c-.45 0-.9-.06-1.34-.2-1.47-.44-2.67-1.61-3.3-3.2-.58-1.46-.65-3.16-.2-4.8.53-1.95 1.74-3.57 3.31-4.44 1.21-.67 2.57-.84 3.81-.46 1.47.44 2.67 1.61 3.3 3.2.58 1.46.65 3.16.2 4.8-.53 1.95-1.74 3.57-3.31 4.44-.79.44-1.64.66-2.47.66zm-1.49-7.28c-.51 1.86.2 3.48 1.15 3.77.35.11.73.05 1.13-.18.74-.41 1.36-1.28 1.64-2.32.51-1.87-.2-3.48-1.15-3.77-.35-.11-.73-.05-1.13.18-.74.41-1.36 1.28-1.64 2.32z"></path>
                    <g>
                      <path
                        fill="#d8b6ff"
                        fillRule="evenodd"
                        d="M75.23 479.57c-.98 1.63-.76 3.54.5 4.28 1.26.73 3.07.01 4.05-1.62.98-1.63.76-3.54-.5-4.28s-3.07-.01-4.05 1.62z"
                      ></path>
                      <path d="M76.83 485.87c-.69 0-1.36-.17-1.98-.53-.9-.53-1.55-1.41-1.82-2.48-.34-1.34-.08-2.87.71-4.18 1.49-2.47 4.31-3.45 6.41-2.22.9.53 1.55 1.41 1.82 2.48.34 1.34.08 2.87-.71 4.18-1.05 1.75-2.77 2.75-4.43 2.75zm-.12-5.41c-.37.61-.41 1.2-.32 1.54.03.12.09.28.21.35.27.16 1.12-.06 1.69-1.01.37-.61.41-1.2.32-1.54-.03-.12-.09-.28-.21-.35-.27-.16-1.12.06-1.69 1.01z"></path>
                    </g>
                    <g>
                      <path
                        fill="#d8b6ff"
                        fillRule="evenodd"
                        d="M71.04 485.52c-1.25 1.14-1.53 2.78-.63 3.66.91.88 2.66.66 3.91-.48 1.25-1.14 1.53-2.78.63-3.66-.91-.88-2.66-.66-3.91.48z"
                      ></path>
                      <path d="M71.88 491.45c-1.01 0-1.96-.34-2.67-1.03-.7-.67-1.07-1.61-1.06-2.62.02-1.28.65-2.58 1.72-3.56 1.95-1.78 4.7-1.97 6.28-.45.7.67 1.07 1.61 1.06 2.62-.02 1.28-.65 2.58-1.72 3.56-1.07.97-2.38 1.47-3.61 1.47zm-.26-3.51c.13.1.86.09 1.53-.52.57-.52.62-1.03.58-1.14-.13-.1-.86-.09-1.53.52-.57.52-.62 1.03-.58 1.14zm0 0zm-.59-2.42z"></path>
                    </g>
                  </g>
                  <g>
                    <path d="M76.35 423.14c-.93 0-1.76-.58-2.09-1.45a.627.627 0 01.59-.85c.28 0 .51.18.6.42a.96.96 0 001.8-.01v-.02a.64.64 0 01.82-.37c.33.12.49.48.37.81v.02c-.33.87-1.17 1.45-2.09 1.45zm-.87-1.67zM85.84 419.16c-.32 0-.63-.14-.84-.41l-.15-.19a2.386 2.386 0 00-3.21-.47l-.37.26c-.49.34-1.17.22-1.51-.27-.34-.49-.22-1.17.27-1.51l.37-.26c1.95-1.35 4.65-.96 6.13.89l.15.19c.37.47.3 1.15-.17 1.52-.2.16-.44.24-.68.24zM66.59 419.32a1.086 1.086 0 01-.76-1.85l.57-.57a4.541 4.541 0 015.31-.83l1.03.53c.53.27.74.93.46 1.46-.27.53-.93.74-1.46.46l-1.03-.53c-.93-.48-2.04-.31-2.78.43l-.57.57c-.21.21-.49.32-.77.32z"></path>
                  </g>
                </g>
              </g>
              <path
                fill="none"
                stroke="#8747cc"
                strokeLinecap="round"
                strokeMiterlimit="10"
                strokeWidth="4"
                d="M1438.69 166.42v551.65c0 8.28-6.72 14.99-15 14.99h-301.37c-2.02 0-3.66-1.63-3.66-3.66V155.09c0-2.02 1.63-3.67 3.66-3.67h301.37c8.28 0 15 6.72 15 15zM115.94 166.42v551.65c0 8.28 6.71 15 15 15h969.41c2.02 0 3.66-1.64 3.66-3.66V155.09c0-2.02-1.64-3.66-3.66-3.66H130.93c-8.28 0-15 6.71-15 15z"
              ></path>
              <g>
                <path
                  fill="#705f82"
                  d="M970.72 151.42c8.28 19.38 14.3 54.12 20.83 44.15 6.52-9.97-.15-44.15-.15-44.15h-20.67zM758.5 733.06h13.29c10.28-42.28-2.84-28.94-13.29 0zM1438.43 635.18v11.86c-8.37-4.07-19.67-10.47-27.23-18.71-.78-.85.09-2.2 1.19-1.83l26.04 8.68z"
                  opacity="0.4"
                ></path>
                <path
                  fill="#8747cc"
                  d="M960.83 126.34c4.75 9.51 8.69 25.09 8.69 25.09h23.38l-1.36-25.08h-30.71zM1455.5 640.61v15.71c-4.41-1.65-10.53-4.12-17.06-7.31v-12.84l17.06 4.44z"
                ></path>
                <path fill="#8747cc" d="M754.71 733.06L744.34 757.51 767.72 757.33 771.79 733.07 754.71 733.06z"></path>
              </g>
              <g>
                <path
                  fill="#bc83fb"
                  d="M1010.03 112.87c0 38.55-13.29 88.19-19.1 88.19-6.89 0-11.13-51.7-18.92-85.27l38.02-2.92z"
                ></path>
                <path
                  fill="#8747cc"
                  d="M1464.58 637.41l-.74 9.28c-2.12-.15-4.26-.37-6.38-.67-11.76-1.62-23.43-5.43-33.35-10.27-33.52-16.35-1.64-15.87 34.69 1.29 1.86.88 3.92.97 5.78.37z"
                ></path>
                <path
                  fill="#bc83fb"
                  d="M770.21 788.58c16.22-43.22 12.74-84.85 5.88-84.85s-9.18 61.08-48.51 103.67c3.57 15.19 42.63-18.82 42.63-18.82z"
                ></path>
              </g>
            </g>
            <g fill="#0e0e0e">
              <ellipse cx="611.72" cy="93.74" rx="6.08" ry="4.74"></ellipse>
              <ellipse cx="66.59" cy="289.87" rx="4.74" ry="6.08" transform="rotate(-60 66.595 289.873)"></ellipse>
              <circle cx="81.29" cy="194.53" r="4.32"></circle>
              <circle cx="297.96" cy="790.72" r="4.32"></circle>
              <circle cx="5.61" cy="190.61" r="5.61"></circle>
              <ellipse cx="567.46" cy="47.79" rx="4.91" ry="4.24" transform="rotate(-45 567.456 47.792)"></ellipse>
              <circle cx="597.83" cy="109.83" r="4.31"></circle>
              <circle cx="1469.33" cy="581.4" r="4.31"></circle>
              <ellipse cx="943.23" cy="107.56" rx="6.19" ry="5.86" transform="rotate(-45 943.233 107.56)"></ellipse>
              <ellipse
                cx="1531.6"
                cy="516.04"
                rx="6.19"
                ry="5.86"
                transform="rotate(-35.03 1531.623 516.042)"
              ></ellipse>
              <ellipse
                cx="1510.02"
                cy="491.23"
                rx="3.87"
                ry="4.87"
                transform="rotate(-80.03 1510.028 491.222)"
              ></ellipse>
              <ellipse cx="765.95" cy="828.56" rx="6.19" ry="5.86" transform="rotate(-45 765.952 828.562)"></ellipse>
              <ellipse cx="275.86" cy="808.31" rx="5.99" ry="6.99" transform="rotate(-83.94 275.904 808.334)"></ellipse>
              <ellipse cx="706.05" cy="784.17" rx="4.25" ry="4.49" transform="rotate(-7.73 705.82 783.94)"></ellipse>
              <ellipse cx="843.48" cy="82.38" rx="4.27" ry="4.94" transform="rotate(-70.18 843.518 82.369)"></ellipse>
              <ellipse cx="596.81" cy="790.13" rx="4.91" ry="5.68" transform="rotate(-51.43 596.79 790.115)"></ellipse>
              <ellipse cx="1022.24" cy="92.59" rx="8.21" ry="5.83" transform="rotate(-79.92 1022.256 92.576)"></ellipse>
            </g>
          </g>
        </svg>
      </>
    </div>
  );
};
